Trees

[hide private]
[frames] | no frames]

## Module Hierarchy

- GoogleSearch_services
- GoogleSearch_services_types
- PyZ3950_parsetab
- baseObjects
- baseStore
- bootstrap
- c3errors
- configParser
- database
- document
- documentFactory
- documentStore
- dynamic
- extractor
- index
- indexStore
- logger
- multivalent
- normalizer
- objectStore
- parser
- permissionHandler
- postgres
- preParser
- protocolMap
- queryFactory
- queryStore
- record
- recordStore
- resultSet
- resultSetStore
- server
- srbErrors
- srboo
- srwExtensions
- textmining

- textmining.TsujiiC3
- textmining.tmDocumentFactory
- textmining.tmNormalizer
- textmining.tmPreParser
- textmining.tmTransformer

- transformer
- user
- utils
- workflow
- XPathProcessor
- z3950_utils

## Class Hierarchy

- Ft.Xml.Domlette._Reader: Base class for all XML readers.
  - Ft.Xml.Domlette.NonvalidatingReaderBase: Base class to be used by all non-validating readers.
    - parser.FtParser: 4Suite based Parser.
- GoogleSearch_services.GoogleSearchBindingSOAP
- GoogleSearch_services.GoogleSearchServiceInterface
  - GoogleSearch_services.GoogleSearchServiceLocator
- GoogleSearch_services_types.urn_GoogleSearch
- ZSI.TC.TypeCode: The parent class for all parseable SOAP types.
  - ZSI.TCcompound.Array: An array.
    - GoogleSearch_services_types.urn_GoogleSearch.ResultElementArray_Def
    - GoogleSearch_services_types.urn_GoogleSearch.DirectoryCategoryArray_Def
  - ZSI.TCcompound.Struct: A structure.
    - GoogleSearch_services.doSpellingSuggestion
      - GoogleSearch_services.doSpellingSuggestionWrapper: wrapper for rpc:encoded message
    - GoogleSearch_services_types.urn_GoogleSearch.ResultElement_Def
    - GoogleSearch_services.doGetCachedPage
      - GoogleSearch_services.doGetCachedPageWrapper: wrapper for rpc:encoded message
    - GoogleSearch_services.doSpellingSuggestionResponse
      - GoogleSearch_services.doSpellingSuggestionResponseWrapper: wrapper for rpc:encoded message
    - GoogleSearch_services_types.urn_GoogleSearch.DirectoryCategory_Def
    - GoogleSearch_services.doGoogleSearchResponse
      - GoogleSearch_services.doGoogleSearchResponseWrapper: wrapper for rpc:encoded message
    - GoogleSearch_services.doGetCachedPageResponse
      - GoogleSearch_services.doGetCachedPageResponseWrapper: wrapper for rpc:encoded message
    - GoogleSearch_services.doGoogleSearch
      - GoogleSearch_services.doGoogleSearchWrapper: wrapper for rpc:encoded message
    - GoogleSearch_services_types.urn_GoogleSearch.GoogleSearchResult_Def
- baseObjects.Document: A Document is the raw data which will become a record.
  - document.StringDocument
- baseObjects.Record: Records in the system are stored in an XML form.
  - record.MarcRecord
  - record.DomRecord
    - record.MinidomRecord
    - record.LxmlRecord
    - record.FtDomRecord
  - record.SaxRecord
- baseObjects.ResultSet: A collection of records, typically created as the result of a search on a database.
  - resultSet.BitmapResultSet
  - resultSet.RankedResultSet
    - resultSet.SimpleResultSet
      - resultSet.ArrayResultSet
- baseObjects.Session: An object to be passed around amongst the processing objects to maintain a session.
- baseStore.PostgresStore
  - recordStore.PostgresRecordStore
- bootstrap.BootstrapDocument
- bootstrap.BootstrapParser
- bootstrap.BootstrapRecord
- bootstrap.BootstrapSession
- bootstrap.BootstrapUser
- documentFactory.BaseDocumentStream
  - documentFactory.ClusterDocumentStream
  - documentFactory.TermHashDocumentStream
  - documentFactory.MultipleDocumentStream
    - documentFactory.FtpDocumentStream
    - documentFactory.DirectoryDocumentStream
      - documentFactory.ZipDocumentStream
      - documentFactory.LocateDocumentStream
    - documentFactory.HttpDocumentStream
      - documentFactory.SrwDocumentStream
      - documentFactory.OpensearchDocumentStream
      - documentFactory.OaiDocumentStream
      - documentFactory.SruDocumentStream
      - documentFactory.SyndicationDocumentStream
      - documentFactory.GoogleDocumentStream
    - documentFactory.TarDocumentStream
    - documentFactory.SrbDocumentStream
  - documentFactory.ComponentDocumentStream
  - documentFactory.XmlDocumentStream
  - documentFactory.MarcDocumentStream
  - postgres.PostgresDocumentStream
  - documentFactory.RemoteDocumentStream
    - documentFactory.SQLDocumentStream
    - documentFactory.FtpDocumentStream
    - documentFactory.Z3950DocumentStream
    - documentFactory.SrbDocumentStream
  - textmining.tmDocumentFactory.EnjuRecordDocumentStream
- documentFactory.UrllibUnicodeFileThing
- exceptions.Exception: Common base class for all exceptions.
  - c3errors.C3Exception
    - c3errors.ObjectAlreadyExistsException
    - c3errors.ConfigFileException
    - c3errors.FileDoesNotExistException
    - workflow.WorkflowException
    - c3errors.ExternalSystemException
    - record.NumericPredicateException
    - c3errors.PermissionException
    - c3errors.ObjectDoesNotExistException
  - srboo.SrbException
- multivalent.MultivalentClient
- object: The most base type
  - srboo.SrbConnection
  - baseStore.BdbIter
    - recordStore.MarcIter
    - recordStore.BdbRecordIter
    - documentStore.BdbDocIter
  - baseObjects.ResultSetItem: An object representing a pointer to a Record, with result set specific metadata.
    - resultSet.SimpleResultSetItem
  - srboo.SrbFile
  - utils.SimpleBitfield
  - configParser.C3Object
    - baseObjects.PreParser: A PreParser takes a Document and creates a second one.
      - textmining.tmPreParser.PosPreParser: Base class for deriving Part of Speech PreParsers
        - textmining.tmPreParser.TsujiiTextPosPreParser
        - textmining.tmPreParser.EnjuTextPreParser
        - textmining.tmPreParser.TsujiiXMLPosPreParser
      - preParser.PrintableOnlyPreParser: Replace or Strip non printable characters
      - preParser.MarcToXmlPreParser: Convert MARC into MARCXML
      - preParser.HtmlTidyPreParser: Calls Tidy utility to turn HTML into XHTML for parsing
      - multivalent.MvdPdfPreParser: Multivalent Pre Parser to turn PDF into XML
      - preParser.PdfToTxtPreParser: Convert PDF to text via pdftotext utility
      - textmining.tmPreParser.TsujiiChunkerPreParser
      - preParser.AmpPreParser: Escape lone ampersands in otherwise XML text
      - preParser.B64EncodePreParser: Encode document in Base64
      - preParser.SgmlPreParser: Convert SGML into XML
      - preParser.GzipPreParser: Gunzip a gzipped document
      - preParser.TagStripPreParser: Strip only named tags from the document eg script, style
      - textmining.tmPreParser.GeniaTextPreParser: Take the full output from Genia and reconstruct the document, maybe with stems ('useStem') and/or PoS tags ('pos')
      - preParser.PdfToXmlPreParser: pdftohtml wrapper to turn PDF into XML
      - preParser.HtmlSmashPreParser: Attempts to reduce HTML to its raw text
      - preParser.BzipPreParser
      - preParser.UrlPreParser
        - preParser.OpenOfficePreParser: Use OpenOffice server to convert documents into OpenDocument XML
      - preParser.NormalizerPreParser: Calls a named Normalizer to do the conversion
      - preParser.B64DecodePreParser: Decode document from Base64
      - preParser.RegexpSmashPreParser: Either strip, replace or keep data which matches a given regular expression
      - preParser.MarcToSgmlPreParser: Convert MARC into Cheshire2's MarcSgml
      - preParser.CharacterEntityPreParser: Transform latin-1 and broken character entities into numeric character entities.
      - multivalent.MultivalentPreParser
      - preParser.TxtToXmlPreParser: Minimally wrap text in &lt;data&gt; xml tags
    - baseStore.SrbStore: Storage Resource Broker based storage
      - recordStore.SrbRecordStore
      - documentStore.SrbDocumentStore
      - baseStore.SrbBdbCombineStore: Combined BerkeleyDB in SRB based Storage
        - recordStore.CachingSrbRecordStore
        - documentStore.CachingSrbDocumentStore
        - recordStore.CachingSrbRemoteWriteRecordStore
    - baseObjects.Logger
      - logger.SimpleLogger
        - logger.FunctionLogger
    - baseObjects.IndexStore: A persistent storage mechanism for extracted terms.
      - postgres.PostgresIndexStore
      - indexStore.BdbIndexStore
        - indexStore.C2IndexStore: Use C2 style indexes, only one recordStore
    - baseObjects.Server: A Server object is a collection point for other objects, and an initial entry into the system for requests from a ProtocolHandler.
      - server.SimpleServer
    - baseObjects.QueryFactory
      - queryFactory.SimpleQueryFactory
    - baseObjects.Index: An Index is an object which defines an access point into records and is responsable for extracting that information from them.
      - index.RecordIdentifierIndex
      - index.SimpleIndex
        - index.ArrayIndex
          - index.ProximityArrayIndex
        - index.BitmapIndex
        - index.ClusterExtractionIndex
        - index.RangeIndex
        - index.ProximityIndex: Need to use prox extractor
        - postgres.PostgresIndex
    - baseObjects.Transformer: A Transformer is the opposite of a Parser.
      - transformer.XmlTransformer: Return the raw XML string of the record
      - transformer.XmlRecordStoreTransformer: Wrap the data with the record's metadata.
      - textmining.tmTransformer.PosTransformer
        - textmining.tmTransformer.TsujiiXPathTransformer
        - textmining.tmTransformer.TsujiiTextPosTransformer
      - transformer.GRS1Transformer: Create representation of the XML tree in Z39.50's GRS1 format
      - transformer.CSVTransformer: Create simple CSV format from indexes specified
      - transformer.LxmlXsltTransformer: XSLT transformer using Lxml implementation.
      - transformer.FilepathTransformer: Returns record.id as an identifier, in raw SAX events.
      - transformer.GrsMapTransformer: Create a particular GRS1 instance, based on a configured map of XPath to GRS1 element.
      - transformer.XsltTransformer: 4Suite based XSLT transformer.
    - baseObjects.ProtocolMap: Protocol maps map from an incoming query type to internal indexes based on some specification.
      - protocolMap.ZeerexProtocolMap
        - protocolMap.UpdateProtocolMap
        - protocolMap.CQLProtocolMap
        - protocolMap.C3WepProtocolMap
        - protocolMap.Z3950ProtocolMap
    - baseObjects.ObjectStore: An interface to a persistent storage mechanism for configured Cheshire3 objects.
      - objectStore.BdbObjectStore
      - baseObjects.QueryStore: An interface to persistent storage for Queries.
        - queryStore.SimpleQueryStore
      - baseObjects.RecordStore: A persistent storage mechanism for Records.
        - recordStore.SimpleRecordStore
          - recordStore.RemoteSlaveRecordStore
          - postgres.PostgresRecordStore
          - recordStore.ParsingRecordStore
            - recordStore.MarcRecordStore
          - recordStore.BdbRecordStore
            - recordStore.RemoteWriteRecordStore: Listen for records and write
            - objectStore.BdbObjectStore
      - baseObjects.DocumentStore: An interface to a persistent storage mechanism for Documents and their associated metadata.
        - documentStore.SimpleDocumentStore
          - documentStore.BdbDocumentStore
      - baseObjects.ResultSetStore: A persistent storage mechanism for result sets.
        - resultSetStore.SimpleResultSetStore
          - resultSetStore.BdbResultSetStore
            - resultSetStore.BdbResultSetStore2
          - postgres.PostgresResultSetStore
    - baseObjects.Workflow: A workflow is similar to the process chain concept of an index, but behaves at a more global level.
      - workflow.SimpleWorkflow: Default workflow implementation.
        - workflow.CachingWorkflow: Slightly faster workflow implementation that caches the objects.
    - baseObjects.Parser: Normally a simple wrapper around an XML parser, these objects can be viewed as Record Factories.
      - parser.LxmlRelaxNGParser
      - parser.BaseParser
        - parser.FtParser: 4Suite based Parser.
        - parser.FtSaxParser: 4Suite SAX based Parser.
        - parser.MarcParser: Creates MarcRecords which fake the Record API for Marc
        - parser.LxmlParser: lxml based Parser.
        - parser.MinidomParser: Use default Python Minidom implementation to parse document
        - parser.PassThroughParser: Copy the data from a document (eg list of sax events or a dom tree) into an appropriate record object
        - parser.XmlRecordStoreParser: Metadata wrapping Parser for RecordStores.
        - parser.SaxParser: Default SAX based parser.
      - parser.LxmlSchemaParser
    - baseObjects.Database: A Database is a collection of Records and Indexes.
      - database.SimpleDatabase: Default database implementation
    - baseObjects.DocumentFactory: Object Docs
      - textmining.TsujiiC3.EnjuGroupDocumentStream
      - documentFactory.BaseDocumentFactory
        - postgres.PostgresDocumentFactory
        - documentFactory.ComponentDocumentFactory
    - xpathProcessor.SimpleXPathProcessor
      - XPathProcessor.SpanExtractor
    - baseStore.SimpleStore: Base Store implementation.
      - postgres.PostgresStore
        - postgres.PostgresResultSetStore
        - postgres.PostgresRecordStore
        - postgres.PostgresIndexStore
      - baseStore.BdbStore: Berkeley DB based storage
        - recordStore.BdbRecordStore
          - recordStore.RemoteWriteRecordStore: Listen for records and write
          - objectStore.BdbObjectStore
        - documentStore.BdbDocumentStore
        - queryStore.SimpleQueryStore
        - resultSetStore.BdbResultSetStore
          - resultSetStore.BdbResultSetStore2
    - baseObjects.XPathProcessor: An XPathProcessor is a simple wrapper around an XPath.
    - baseObjects.Extractor: An Extractor is a processing object called by an Index with the value of an evaluated XPath expression or with a string.
      - extractor.SimpleExtractor: Base extractor.
        - extractor.KeywordExtractor: Extracts keywords from the text
          - extractor.ProximityExtractor: Extract keywords and maintain information for proximity searches
            - extractor.ExactProximityExtractor: Extract exact text with proximity information.
        - extractor.DateExtractor: Extracts a single date.
    - baseObjects.Normalizer: Normalizer objects are chained after Extractors in order to transform the data from the record or query.
      - normalizer.SimpleNormalizer: Base normalizer.
        - textmining.tmNormalizer.PosTypeNormalizer: Filter by part of speech tags.
        - normalizer.PhraseStemNormalizer: Use a Snowball stemmer to stem multiple words in a phrase (eg from PosPhraseNormalizer)
        - normalizer.ArticleNormalizer: Remove leading english articles (the, a, an)
        - normalizer.ExactExpansionNormalizer
        - normalizer.DateStringNormalizer: Turns a Date object into ISO8601 format
        - normalizer.RangeNormalizer: Should normalise ranges...
        - normalizer.DataExistsNormalizer: Return '1' if any data exists, otherwise '0'
        - normalizer.ReverseNormalizer: Reverse string (eg for left truncation)
        - normalizer.WordExpansionNormalizer
        - normalizer.DiacriticNormalizer: Slow implementation of Unicode 4.0 character decomposition.
        - textmining.tmNormalizer.PosPhraseNormalizer: Extract statistical multi-word noun phrases.
        - normalizer.StringIntNormalizer: Turn an integer into a 0 padded string, 12 chrs long
        - normalizer.StoplistNormalizer: Remove words that match a stopword list
        - textmining.tmNormalizer.GeniaTextNormalizer: Take the full output from Genia and reconstruct the document, maybe with stems ('useStem') and/or PoS tags ('pos')
        - normalizer.IntNormalizer: Turn a string into an integer
        - normalizer.RegexpNormalizer: Either strip, replace or keep data which matches a given regular expression
        - normalizer.TermExistsNormalizer: Un-stoplist anonymizing normalizer.
        - textmining.tmNormalizer.GeniaStemNormalizer: Take output from GeniaNormalizer and return stems as terms
        - normalizer.SpaceNormalizer: Reduce multiple whitespace to single space character
        - normalizer.CaseNormalizer: Reduce text to lower case
        - textmining.tmNormalizer.PosNormalizer: Base class for deriving Part of Speech Normalizers
          - textmining.tmNormalizer.ExactGeniaNormalizer
          - textmining.tmNormalizer.TsujiiPosNormalizer
          - textmining.tmNormalizer.EnjuNormalizer
          - textmining.tmNormalizer.UnparsedGeniaNormalizer
          - textmining.tmNormalizer.GeniaNormalizer
        - normalizer.PossessiveNormalizer: Remove trailing 's or s' from words
        - normalizer.NumericEntityNormalizer: Replace characters matching regular expression with the equivalent numeric character entity
        - normalizer.KeywordNormalizer: Given a string, keyword it with proximity.
          - textmining.tmNormalizer.PosKeywordNormalizer: Turn string into keywords, but respecting Part of Speech tags
        - normalizer.StemNormalizer: Use a Snowball stemmer to stem the terms
    - baseObjects.User: An object representing a user of the system to allow for convenient access to properties such as username, password and rights metadata.
      - user.SimpleUser
- permissionHandler.PermissionHandler
- record.SaxToDomHandler
- record.SaxToXmlHandler
- textmining.TsujiiC3.EnjuObject
  - textmining.tmPreParser.EnjuTextPreParser
  - textmining.tmNormalizer.EnjuNormalizer
- textmining.TsujiiC3.GeniaObject
  - textmining.tmNormalizer.GeniaNormalizer
  - textmining.tmNormalizer.UnparsedGeniaNormalizer
  - textmining.tmNormalizer.ExactGeniaNormalizer
- textmining.TsujiiC3.SimpleTokenizer
- textmining.TsujiiC3.TsujiiObject
  - textmining.tmTransformer.TsujiiXPathTransformer
  - textmining.tmPreParser.TsujiiTextPosPreParser
  - textmining.tmNormalizer.TsujiiPosNormalizer
  - textmining.tmTransformer.TsujiiTextPosTransformer
  - textmining.tmPreParser.TsujiiXMLPosPreParser
- utils.reader
- xml.sax.handler.ContentHandler: Interface for receiving logical document content events.
  - resultSet.DeserializationHandler
  - record.SaxContentHandler